@@ -548,15 +548,16 @@ class Predicate(Expr):
 
         for item in items:
             # save the current item into var_self for Self()
-            # set var_finding False to
-            # start new finding process for the nested expr: self.idx
-            with temporary_set(var_self, item), temporary_set(
-                var_finding, False
-            ):
+            with temporary_set(var_self, item):
                 _, value = item
-                rv = self.expr.find(value)
+                # set var_finding False to
+                # start new finding process for the nested expr: self.idx
+                with temporary_set(var_finding, False):
+                    rv = self.expr.find(value)
+
                 if rv and rv[0]:
                     filtered_items.append(value)
+
         return filtered_items
 
 
@@ -628,14 +629,40 @@ class Slice(Expr):
 
 class Brace(Expr):
     """
-    Brace the mixed expression to be executed first.
+    Brace groups part of expression,
+    uses sub-expression to find the target data,
+    and wraps the found result as an array.
+
+    >>> p = Root().Array().Name("a"); print(p)
+    $[*].a
+    >>> p.find([{"a": 1}])
+    [1]
+
+    >>> p = Brace(p); print(p)
+    ($[*].a)
+    >>> p.find([{"a": 1}])
+    [[1]]
+
+    It seems to be useless but makes chaining filtering become possible.
+    The expressions like `"$[@ < 100][@ >= 50]"` can not perform chaining filtering.
+    Because the Preidcate (and Array) class always unarrays the found elements to
+    avoid the found result looking like `[[[[[[[...]]]]]]]`.
+    So the right way to do chaining filter is that it should use with Brace class.
+
+    >>> p = Brace(Root().Predicate(Self() < 100)).Predicate(Self() >= 50)
+    >>> print(p)
+    ($[@ < 100])[@ >= 50]
+    >>> p.find([100, 99, 50, 1])
+    [99, 50]
+
+    Generally, we will use And expresion do that. e.g. `"$[@ < 100 and @ >= 50]"`
 
     >>> p = Brace(
     ...     Root().Array().Name("a")
     ... ).Predicate(Self() == 1)
     >>> print(p)
     ($[*].a)[@ = 1]
-    >>> p.find([{"a": 1}, {"a": 2}, {"a": 1}])
+    >>> p.find([{"a": 1}, {"a": 2}, {"a": 1}, {}])
     [1, 1]
 
     """
